@@ -1,13 +1,11 @@
 """
-Mixins that are in conjunction with DRF serializers and resolver data
-TODO: these are highly coupled to serializers, should they still be?
+Mixins that are in DRF serializers and resolver data
 """
 import enum
 
 from django.db.models.deletion import IntegrityError, ProtectedError
 
 
-
 class ListModelMixin:
     """
     List a queryset.
@@ -16,7 +14,7 @@ class ListModelMixin:
     pagination_class = None
 
     def list(self, request, *args, **kwargs):
-        queryset = self.filter_queryset(self.get_queryset())
+        queryset = self.get_queryset()
 
         page = self.paginate_queryset(queryset)
         if page is not None:
@@ -42,12 +40,17 @@ class ListModelMixin:
         """
         if self.paginator is None:
             return None
-        return self.paginator.paginate_queryset(
-            queryset, self.request, view=self, **kwargs
-        )
+        return self.paginator.paginate_queryset(queryset, self.request, view=self, **kwargs)
 
 
 class InputMixin:
+    """
+    Take an input operation argument and return the data.
+
+    This mixin is pretty limited, nested enums under other input types will not be
+    converted into their value. FIX/CHANGE
+    """
+
     input_arg = "input"
     convert_enums = True
 
@@ -89,9 +92,7 @@ class UpdateModelMixin:
     def update(self, request, *args, **kwargs):
         partial = kwargs.pop("partial", False)
         instance = self.get_object()
-        serializer = self.get_serializer(
-            instance, data=self.get_input_data(), partial=partial
-        )
+        serializer = self.get_serializer(instance, data=self.get_input_data(), partial=partial)
         valid = serializer.is_valid(raise_exception=False)
 
         obj = instance
